@@ -8,7 +8,7 @@
 #######################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '1.0-1'
+Version = '1.1-1'
 
 import os
 import sys
@@ -98,10 +98,7 @@ def getCurrent():
          for line in string.splitlines():
              line=line.split('=')
              if line[0] in configVars:
-                 if line[1].isdigit() == False:
-                     dataVars[line[0]]=line[1]
-                 else:
-                     dataVars[line[0]]=int(line[1])
+                 dataVars[line[0]]=line[1]
      except IOError:
          message = 'Reading the configuration settings gave a FATAL ERROR while loading\nConfiguration file does not exist or cannot be read.'
          showMessage(message)
@@ -213,7 +210,7 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
     def open_bugtracker(self):
         QDesktopServices.openUrl(QUrl('https://bugs.maemo.org'))
 
-class MyMainWindow(QtGui.QMainWindow):
+class CSSUfeaturesMainWindow(QtGui.QMainWindow):
         def __init__(self, parent=None):
              
              ##Build parent user interface
@@ -266,13 +263,14 @@ class MyMainWindow(QtGui.QMainWindow):
 
              #Get the values from the configuration file.
              getCurrent()
+
              #Set them in the GUI.
-             self.ui.comboBoxZoomPress.setCurrentIndex(dataVars['zoom_on_press'])
-             self.ui.comboBoxBlurless.setCurrentIndex(dataVars['blurless'])
-             self.ui.comboBoxTaskSwitcher.setCurrentIndex(dataVars['taskswitcher'])
-             self.ui.comboBoxRotationAxis.setCurrentIndex(dataVars['zaxisrotation'])
-             self.ui.comboBoxForcedRotation.setCurrentIndex(dataVars['forcerotation'])
-             self.ui.comboBoxTactile.setCurrentIndex(dataVars['tactilepopups'])
+             self.ui.comboBoxZoomPress.setCurrentIndex(int(dataVars['zoom_on_press']))
+             self.ui.comboBoxBlurless.setCurrentIndex(int(dataVars['blurless']))
+             self.ui.comboBoxTaskSwitcher.setCurrentIndex(int(dataVars['taskswitcher']))
+             self.ui.comboBoxRotationAxis.setCurrentIndex(int(dataVars['zaxisrotation']))
+             self.ui.comboBoxForcedRotation.setCurrentIndex(int(dataVars['forcerotation']))
+             self.ui.comboBoxTactile.setCurrentIndex(int(dataVars['tactilepopups']))
              self.ui.lineEditParallax.setText(dataVars['parallax'])
              
              message = 'The CURRENT configuration options are shown.'
@@ -367,8 +365,9 @@ class MyMainWindow(QtGui.QMainWindow):
                  message = 'The new settings have been successfully saved to the system and theme folders.'
 
              showMessage(message)
-            
-if __name__ == "__main__":
+
+class CSSUfeaturesMain():             
+#if __name__ == "__main__":
      
     ##Check with what priviledges the GUI has been executed
     if os.geteuid() == 0:
@@ -392,6 +391,6 @@ if __name__ == "__main__":
         
     ##Open Dialog Window
     app = QtGui.QApplication(sys.argv)
-    myapp = MyMainWindow()
+    myapp = CSSUfeaturesMainWindow()
     myapp.show()
     sys.exit(app.exec_())
\ No newline at end of file
